@@ -33,8 +33,14 @@ class PatternEngine:
         self.flags = []
         self.is_active = False
 
+    def encode_pattern(self, pattern: str, skip_boundaries: bool) -> bytes:
+        if not skip_boundaries:
+            pattern = fr"\b{pattern}\b"
+        pattern = pattern.encode(self.encoding)
+        return pattern
+
     def add_rule(self, rule: Rule):
-        pattern: bytes = rf"\b{rule.pattern}\b".encode(self.encoding)
+        pattern = self.encode_pattern(rule.pattern, rule.skip_boundaries)
         self.patterns.append(pattern)
         self.ids.append(rule.id)
         flag = hs.HS_FLAG_SOM_LEFTMOST
